@@ -28,6 +28,7 @@
 
 namespace Boo.Lang.Compiler.Steps
 {	
+	using System.Text;
 	using Boo.Lang.Compiler;
 	using Boo.Lang.Compiler.Ast;
 	
@@ -50,25 +51,41 @@ namespace Boo.Lang.Compiler.Steps
 		{
 			CheckMemberName(node);
 			CantBeMarkedAbstract(node);
+			CantBeMarkedPartial(node);
 		}
 		
 		override public void LeaveProperty(Property node)
 		{
 			CheckMemberName(node);
 			CantBeMarkedTransient(node);
+			CantBeMarkedPartial(node);
 			CheckExplicitImpl(node);
+			CheckModifierCombination(node);
+		}
+
+		override public void LeaveConstructor(Constructor node)
+		{
+			CantBeMarkedTransient(node);
+			CantBeMarkedPartial(node);
+			CheckExtensionSemantics(node);
+			CannotReturnValue(node);
 		}
 		
 		override public void LeaveMethod(Method node)
 		{
 			CheckMemberName(node);
 			CantBeMarkedTransient(node);
+			CantBeMarkedPartial(node);
 			CheckExplicitImpl(node);
+			CheckExtensionSemantics(node);
+			CheckModifierCombination(node);
 		}
 		
 		override public void LeaveEvent(Event node)
 		{
 			CheckMemberName(node);
+			CantBeMarkedPartial(node);
+			CheckModifierCombination(node);
 		}
 		
 		override public void LeaveInterfaceDefinition(InterfaceDefinition node)
@@ -76,6 +93,7 @@ namespace Boo.Lang.Compiler.Steps
 			CheckMemberName(node);
 			CantBeMarkedAbstract(node);
 			CantBeMarkedTransient(node);
+			CantBeMarkedPartial(node);
 		}
 		
 		override public void LeaveCallableDefinition(CallableDefinition node)
@@ -83,6 +101,7 @@ namespace Boo.Lang.Compiler.Steps
 			CheckMemberName(node);
 			CantBeMarkedAbstract(node);
 			CantBeMarkedTransient(node);
+			CantBeMarkedPartial(node);
 		}
 		
 		override public void LeaveClassDefinition(ClassDefinition node)
@@ -106,7 +125,7 @@ namespace Boo.Lang.Compiler.Steps
 		override public void LeaveBinaryExpression(BinaryExpression node)
 		{
 			if (BinaryOperatorType.Assign == node.Operator
-				&& (node.Right.NodeType != NodeType.AsExpression)
+				&& (node.Right.NodeType != NodeType.TryCastExpression)
 				&& (IsTopLevelOfConditional(node)))
 			{
 				Warnings.Add(CompilerWarningFactory.EqualsInsteadOfAssign(node));
@@ -118,7 +137,7 @@ namespace Boo.Lang.Compiler.Steps
 			Node parent = child.ParentNode;
 			return (parent.NodeType == NodeType.IfStatement
 				|| parent.NodeType == NodeType.UnlessStatement
-				|| parent.NodeType == NodeType.TernaryExpression
+				|| parent.NodeType == NodeType.ConditionalExpression
 				|| parent.NodeType == NodeType.WhenClause
 				|| parent.NodeType == NodeType.StatementModifier
 				|| parent.NodeType == NodeType.ReturnStatement
@@ -136,8 +155,24 @@ namespace Boo.Lang.Compiler.Steps
 			{
 				Error(CompilerErrorFactory.CantHaveDestructorParameters(node));
 			}
+
+			CannotReturnValue(node);
 		}
 
+		private void CannotReturnValue(Method node)
+		{
+			if (node.ReturnType != null)
+			{
+				Error(CompilerErrorFactory.CannotReturnValue(node));
+			}
+		}
+
+		void CheckExtensionSemantics(Method node)
+		{
+			if (MethodImplementationFlags.Extension != (node.ImplementationFlags & MethodImplementationFlags.Extension)) return;
+			if (NodeType.Method == node.NodeType && (node.IsStatic || node.DeclaringType is Module)) return;
+			Error(CompilerErrorFactory.InvalidExtensionDefinition(node));
+		}
 		
 		void CantBeMarkedAbstract(TypeMember member)
 		{
@@ -185,5 +220,36 @@ namespace Boo.Lang.Compiler.Steps
 						node.Name));
 			}
 		}
+		
+		void CheckModifierCombination(TypeMember member)
+		{
+			InvalidCombination(member, TypeMemberModifiers.Static, TypeMemberModifiers.Abstract);
+			InvalidCombination(member, TypeMemberModifiers.Static, TypeMemberModifiers.Virtual);
+			InvalidCombination(member, TypeMemberModifiers.Static, TypeMemberModifiers.Override);
+			
+			if (member.NodeType != NodeType.Field)
+			{
+				InvalidCombination(member, TypeMemberModifiers.Static, TypeMemberModifiers.Final);
+			}
+		}
+		
+		void InvalidCombination(TypeMember member, TypeMemberModifiers mod1, TypeMemberModifiers mod2)
+		{
+			if (!member.IsModifierSet(mod1) || !member.IsModifierSet(mod2)) return;
+			Error(
+				CompilerErrorFactory.InvalidCombinationOfModifiers(
+					member,
+					member.FullName,
+					string.Format("{0}, {1}", mod1.ToString().ToLower(), mod2.ToString().ToLower())));
+		}
+		
+		
+		void CantBeMarkedPartial(TypeMember member)
+		{
+			if (member.IsPartial)
+			{
+				Error(CompilerErrorFactory.CantBeMarkedPartial(member));
+			}
+		}
 	}
 }
