@@ -1,4 +1,4 @@
-#region license
+﻿#region license
 // Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
 // All rights reserved.
 // 
@@ -105,92 +105,96 @@ namespace Boo.Lang.Parser
 		public const int IN = 43;
 		public const int NOT = 44;
 		public const int NULL = 45;
-		public const int OR = 46;
-		public const int OTHERWISE = 47;
-		public const int OVERRIDE = 48;
-		public const int PASS = 49;
-		public const int NAMESPACE = 50;
-		public const int PUBLIC = 51;
-		public const int PROTECTED = 52;
-		public const int PRIVATE = 53;
-		public const int RAISE = 54;
-		public const int REF = 55;
-		public const int RETURN = 56;
-		public const int RETRY = 57;
-		public const int SET = 58;
-		public const int SELF = 59;
-		public const int SUPER = 60;
-		public const int STATIC = 61;
-		public const int SUCCESS = 62;
-		public const int STRUCT = 63;
-		public const int TRY = 64;
-		public const int TRANSIENT = 65;
-		public const int TRUE = 66;
-		public const int TYPEOF = 67;
-		public const int UNLESS = 68;
-		public const int VIRTUAL = 69;
-		public const int WHEN = 70;
-		public const int WHILE = 71;
-		public const int YIELD = 72;
-		public const int EOS = 73;
-		public const int TRIPLE_QUOTED_STRING = 74;
-		public const int DOUBLE_QUOTED_STRING = 75;
-		public const int SINGLE_QUOTED_STRING = 76;
-		public const int ID = 77;
-		public const int LPAREN = 78;
-		public const int RPAREN = 79;
-		public const int ASSIGN = 80;
-		public const int SUBTRACT = 81;
-		public const int LBRACK = 82;
-		public const int COMMA = 83;
-		public const int RBRACK = 84;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 85;
-		public const int DOT = 86;
-		public const int COLON = 87;
-		public const int MULTIPLY = 88;
-		public const int BITWISE_OR = 89;
-		public const int LBRACE = 90;
-		public const int RBRACE = 91;
-		public const int INPLACE_BITWISE_OR = 92;
-		public const int INPLACE_BITWISE_AND = 93;
-		public const int INPLACE_SHIFT_LEFT = 94;
-		public const int INPLACE_SHIFT_RIGHT = 95;
-		public const int CMP_OPERATOR = 96;
-		public const int GREATER_THAN = 97;
-		public const int LESS_THAN = 98;
-		public const int ADD = 99;
-		public const int EXCLUSIVE_OR = 100;
-		public const int DIVISION = 101;
-		public const int MODULUS = 102;
-		public const int BITWISE_AND = 103;
-		public const int SHIFT_LEFT = 104;
-		public const int SHIFT_RIGHT = 105;
-		public const int EXPONENTIATION = 106;
-		public const int INCREMENT = 107;
-		public const int DECREMENT = 108;
-		public const int ONES_COMPLEMENT = 109;
-		public const int INT = 110;
-		public const int LONG = 111;
-		public const int RE_LITERAL = 112;
-		public const int DOUBLE = 113;
-		public const int FLOAT = 114;
-		public const int TIMESPAN = 115;
-		public const int LINE_CONTINUATION = 116;
-		public const int SL_COMMENT = 117;
-		public const int ML_COMMENT = 118;
-		public const int WS = 119;
-		public const int X_RE_LITERAL = 120;
-		public const int NEWLINE = 121;
-		public const int ESCAPED_EXPRESSION = 122;
-		public const int DQS_ESC = 123;
-		public const int SQS_ESC = 124;
-		public const int SESC = 125;
-		public const int RE_CHAR = 126;
-		public const int X_RE_CHAR = 127;
-		public const int RE_ESC = 128;
-		public const int ID_LETTER = 129;
-		public const int DIGIT = 130;
-		public const int HEXDIGIT = 131;
+		public const int OF = 46;
+		public const int OR = 47;
+		public const int OTHERWISE = 48;
+		public const int OVERRIDE = 49;
+		public const int PASS = 50;
+		public const int NAMESPACE = 51;
+		public const int PARTIAL = 52;
+		public const int PUBLIC = 53;
+		public const int PROTECTED = 54;
+		public const int PRIVATE = 55;
+		public const int RAISE = 56;
+		public const int REF = 57;
+		public const int RETURN = 58;
+		public const int RETRY = 59;
+		public const int SET = 60;
+		public const int SELF = 61;
+		public const int SUPER = 62;
+		public const int STATIC = 63;
+		public const int SUCCESS = 64;
+		public const int STRUCT = 65;
+		public const int TRY = 66;
+		public const int TRANSIENT = 67;
+		public const int TRUE = 68;
+		public const int TYPEOF = 69;
+		public const int UNLESS = 70;
+		public const int VIRTUAL = 71;
+		public const int WHEN = 72;
+		public const int WHILE = 73;
+		public const int YIELD = 74;
+		public const int EOS = 75;
+		public const int TRIPLE_QUOTED_STRING = 76;
+		public const int DOUBLE_QUOTED_STRING = 77;
+		public const int SINGLE_QUOTED_STRING = 78;
+		public const int ID = 79;
+		public const int LPAREN = 80;
+		public const int RPAREN = 81;
+		public const int ASSIGN = 82;
+		public const int SUBTRACT = 83;
+		public const int LBRACK = 84;
+		public const int COMMA = 85;
+		public const int RBRACK = 86;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 87;
+		public const int DOT = 88;
+		public const int COLON = 89;
+		public const int MULTIPLY = 90;
+		public const int BITWISE_OR = 91;
+		public const int LBRACE = 92;
+		public const int RBRACE = 93;
+		public const int INPLACE_BITWISE_OR = 94;
+		public const int INPLACE_BITWISE_AND = 95;
+		public const int INPLACE_SHIFT_LEFT = 96;
+		public const int INPLACE_SHIFT_RIGHT = 97;
+		public const int CMP_OPERATOR = 98;
+		public const int GREATER_THAN = 99;
+		public const int LESS_THAN = 100;
+		public const int ADD = 101;
+		public const int EXCLUSIVE_OR = 102;
+		public const int DIVISION = 103;
+		public const int MODULUS = 104;
+		public const int BITWISE_AND = 105;
+		public const int SHIFT_LEFT = 106;
+		public const int SHIFT_RIGHT = 107;
+		public const int EXPONENTIATION = 108;
+		public const int INCREMENT = 109;
+		public const int DECREMENT = 110;
+		public const int ONES_COMPLEMENT = 111;
+		public const int INT = 112;
+		public const int LONG = 113;
+		public const int RE_LITERAL = 114;
+		public const int DOUBLE = 115;
+		public const int FLOAT = 116;
+		public const int TIMESPAN = 117;
+		public const int LINE_CONTINUATION = 118;
+		public const int SL_COMMENT = 119;
+		public const int ML_COMMENT = 120;
+		public const int WS = 121;
+		public const int X_RE_LITERAL = 122;
+		public const int NEWLINE = 123;
+		public const int ESCAPED_EXPRESSION = 124;
+		public const int DQS_ESC = 125;
+		public const int SQS_ESC = 126;
+		public const int SESC = 127;
+		public const int RE_CHAR = 128;
+		public const int X_RE_CHAR = 129;
+		public const int RE_ESC = 130;
+		public const int DIGIT_GROUP = 131;
+		public const int REVERSE_DIGIT_GROUP = 132;
+		public const int ID_LETTER = 133;
+		public const int DIGIT = 134;
+		public const int HEXDIGIT = 135;
 		
 		
 	
@@ -224,70 +228,72 @@ namespace Boo.Lang.Parser
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 51);
-			literals.Add("namespace", 50);
+			literals.Add("public", 53);
+			literals.Add("namespace", 51);
 			literals.Add("break", 13);
-			literals.Add("while", 71);
-			literals.Add("otherwise", 47);
-			literals.Add("raise", 54);
-			literals.Add("typeof", 67);
+			literals.Add("while", 73);
+			literals.Add("otherwise", 48);
+			literals.Add("raise", 56);
+			literals.Add("typeof", 69);
 			literals.Add("and", 10);
 			literals.Add("failure", 29);
 			literals.Add("not", 44);
-			literals.Add("return", 56);
-			literals.Add("pass", 49);
+			literals.Add("return", 58);
+			literals.Add("pass", 50);
 			literals.Add("from", 31);
 			literals.Add("null", 45);
 			literals.Add("def", 20);
 			literals.Add("given", 35);
-			literals.Add("protected", 52);
-			literals.Add("ref", 55);
-			literals.Add("retry", 57);
-			literals.Add("when", 70);
+			literals.Add("protected", 54);
+			literals.Add("ref", 57);
+			literals.Add("retry", 59);
+			literals.Add("when", 72);
 			literals.Add("class", 18);
 			literals.Add("do", 22);
 			literals.Add("except", 28);
 			literals.Add("event", 27);
 			literals.Add("ast", 12);
-			literals.Add("unless", 68);
-			literals.Add("super", 60);
-			literals.Add("set", 58);
-			literals.Add("transient", 65);
+			literals.Add("unless", 70);
+			literals.Add("super", 62);
+			literals.Add("set", 60);
+			literals.Add("transient", 67);
 			literals.Add("constructor", 19);
 			literals.Add("interface", 38);
+			literals.Add("of", 46);
 			literals.Add("is", 40);
 			literals.Add("internal", 39);
 			literals.Add("final", 30);
-			literals.Add("yield", 72);
-			literals.Add("or", 46);
+			literals.Add("yield", 74);
+			literals.Add("or", 47);
 			literals.Add("destructor", 21);
 			literals.Add("if", 42);
-			literals.Add("success", 62);
-			literals.Add("override", 48);
+			literals.Add("success", 64);
+			literals.Add("override", 49);
 			literals.Add("as", 11);
-			literals.Add("try", 64);
+			literals.Add("try", 66);
 			literals.Add("goto", 36);
 			literals.Add("enum", 26);
 			literals.Add("isa", 41);
 			literals.Add("for", 32);
 			literals.Add("char", 17);
-			literals.Add("private", 53);
+			literals.Add("private", 55);
 			literals.Add("false", 33);
-			literals.Add("static", 61);
+			literals.Add("static", 63);
 			literals.Add("abstract", 9);
+			literals.Add("partial", 52);
 			literals.Add("callable", 15);
 			literals.Add("get", 34);
 			literals.Add("continue", 14);
 			literals.Add("cast", 16);
-			literals.Add("struct", 63);
+			literals.Add("struct", 65);
 			literals.Add("else", 24);
 			literals.Add("import", 37);
 			literals.Add("elif", 23);
 			literals.Add("in", 43);
-			literals.Add("self", 59);
+			literals.Add("self", 61);
 			literals.Add("ensure", 25);
-			literals.Add("true", 66);
-			literals.Add("virtual", 69);
+			literals.Add("true", 68);
+			literals.Add("virtual", 71);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -694,23 +700,7 @@ _loop7_breakloop:					;
 			}
 		}
 		else if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (true)) {
-			{ // ( ... )+
-				int _cnt11=0;
-				for (;;)
-				{
-					if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-					{
-						mDIGIT(false);
-					}
-					else
-					{
-						if (_cnt11 >= 1) { goto _loop11_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-					}
-					
-					_cnt11++;
-				}
-_loop11_breakloop:				;
-			}    // ( ... )+
+			mDIGIT_GROUP(false);
 			{
 				if ((cached_LA1=='E'||cached_LA1=='e'))
 				{
@@ -758,23 +748,7 @@ _loop11_breakloop:				;
 						}
 						 }
 					}
-					{ // ( ... )+
-						int _cnt16=0;
-						for (;;)
-						{
-							if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-							{
-								mDIGIT(false);
-							}
-							else
-							{
-								if (_cnt16 >= 1) { goto _loop16_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-							}
-							
-							_cnt16++;
-						}
-_loop16_breakloop:						;
-					}    // ( ... )+
+					mDIGIT_GROUP(false);
 				}
 				else {
 				}
@@ -847,23 +821,7 @@ _loop16_breakloop:						;
 								{
 									{
 										match('.');
-										{ // ( ... )+
-											int _cnt25=0;
-											for (;;)
-											{
-												if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-												{
-													mDIGIT(false);
-												}
-												else
-												{
-													if (_cnt25 >= 1) { goto _loop25_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-												}
-												
-												_cnt25++;
-											}
-_loop25_breakloop:											;
-										}    // ( ... )+
+										mREVERSE_DIGIT_GROUP(false);
 										{
 											if ((cached_LA1=='E'||cached_LA1=='e'))
 											{
@@ -911,23 +869,7 @@ _loop25_breakloop:											;
 													}
 													 }
 												}
-												{ // ( ... )+
-													int _cnt30=0;
-													for (;;)
-													{
-														if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-														{
-															mDIGIT(false);
-														}
-														else
-														{
-															if (_cnt30 >= 1) { goto _loop30_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-														}
-														
-														_cnt30++;
-													}
-_loop30_breakloop:													;
-												}    // ( ... )+
+												mDIGIT_GROUP(false);
 											}
 											else {
 											}
@@ -1079,6 +1021,100 @@ _loop30_breakloop:													;
 		returnToken_ = _token;
 	}
 	
+	protected void mDIGIT_GROUP(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = DIGIT_GROUP;
+		
+		mDIGIT(false);
+		{    // ( ... )*
+			for (;;)
+			{
+				switch ( cached_LA1 )
+				{
+				case '_':
+				{
+					{
+						int _saveIndex = 0;
+						_saveIndex = text.Length;
+						match('_');
+						text.Length = _saveIndex;
+						mDIGIT(false);
+						mDIGIT(false);
+						mDIGIT(false);
+					}
+					break;
+				}
+				case '0':  case '1':  case '2':  case '3':
+				case '4':  case '5':  case '6':  case '7':
+				case '8':  case '9':
+				{
+					mDIGIT(false);
+					break;
+				}
+				default:
+				{
+					goto _loop112_breakloop;
+				}
+				 }
+			}
+_loop112_breakloop:			;
+		}    // ( ... )*
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
+	protected void mREVERSE_DIGIT_GROUP(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = REVERSE_DIGIT_GROUP;
+		
+		{ // ( ... )+
+			int _cnt116=0;
+			for (;;)
+			{
+				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
+				{
+					mDIGIT(false);
+					mDIGIT(false);
+					mDIGIT(false);
+					{
+						if (((cached_LA1=='_'))&&(BooLexer.IsDigit(LA(2))))
+						{
+							int _saveIndex = 0;
+							_saveIndex = text.Length;
+							match('_');
+							text.Length = _saveIndex;
+						}
+						else {
+						}
+						
+					}
+				}
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (true) && (true)) {
+					mDIGIT(false);
+				}
+				else
+				{
+					if (_cnt116 >= 1) { goto _loop116_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+				}
+				
+				_cnt116++;
+			}
+_loop116_breakloop:			;
+		}    // ( ... )+
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	public void mDOT(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -1088,23 +1124,7 @@ _loop30_breakloop:													;
 		{
 			if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
 			{
-				{ // ( ... )+
-					int _cnt39=0;
-					for (;;)
-					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-						{
-							mDIGIT(false);
-						}
-						else
-						{
-							if (_cnt39 >= 1) { goto _loop39_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-						}
-						
-						_cnt39++;
-					}
-_loop39_breakloop:					;
-				}    // ( ... )+
+				mREVERSE_DIGIT_GROUP(false);
 				{
 					if ((cached_LA1=='E'||cached_LA1=='e'))
 					{
@@ -1152,23 +1172,7 @@ _loop39_breakloop:					;
 							}
 							 }
 						}
-						{ // ( ... )+
-							int _cnt44=0;
-							for (;;)
-							{
-								if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-								{
-									mDIGIT(false);
-								}
-								else
-								{
-									if (_cnt44 >= 1) { goto _loop44_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-								}
-								
-								_cnt44++;
-							}
-_loop44_breakloop:							;
-						}    // ( ... )+
+						mDIGIT_GROUP(false);
 					}
 					else {
 					}
@@ -1582,11 +1586,11 @@ _loop44_breakloop:							;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched75 = false;
+		bool synPredMatched63 = false;
 		if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
 		{
-			int _m75 = mark();
-			synPredMatched75 = true;
+			int _m63 = mark();
+			synPredMatched63 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1595,12 +1599,12 @@ _loop44_breakloop:							;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched75 = false;
+				synPredMatched63 = false;
 			}
-			rewind(_m75);
+			rewind(_m63);
 			inputState.guessing--;
 		}
-		if ( synPredMatched75 )
+		if ( synPredMatched63 )
 		{
 			mRE_LITERAL(false);
 			if (0==inputState.guessing)
@@ -1644,7 +1648,7 @@ _loop44_breakloop:							;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt111=0;
+			int _cnt99=0;
 			for (;;)
 			{
 				if ((tokenSet_1_.member(cached_LA1)))
@@ -1653,12 +1657,12 @@ _loop44_breakloop:							;
 				}
 				else
 				{
-					if (_cnt111 >= 1) { goto _loop111_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt99 >= 1) { goto _loop99_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt111++;
+				_cnt99++;
 			}
-_loop111_breakloop:			;
+_loop99_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -1856,7 +1860,7 @@ _loop111_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt90=0;
+			int _cnt78=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -1891,12 +1895,12 @@ _loop111_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt90 >= 1) { goto _loop90_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt78 >= 1) { goto _loop78_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt90++;
+				_cnt78++;
 			}
-_loop90_breakloop:			;
+_loop78_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -1933,11 +1937,11 @@ _loop90_breakloop:			;
 				}
 				else
 				{
-					goto _loop94_breakloop;
+					goto _loop82_breakloop;
 				}
 				
 			}
-_loop94_breakloop:			;
+_loop82_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2221,6 +2225,76 @@ _loop94_breakloop:			;
 		{
 			switch ( cached_LA1 )
 			{
+			case '+':
+			{
+				match('+');
+				break;
+			}
+			case '/':
+			{
+				match('/');
+				break;
+			}
+			case '(':
+			{
+				match('(');
+				break;
+			}
+			case ')':
+			{
+				match(')');
+				break;
+			}
+			case '|':
+			{
+				match('|');
+				break;
+			}
+			case '.':
+			{
+				match('.');
+				break;
+			}
+			case '*':
+			{
+				match('*');
+				break;
+			}
+			case '?':
+			{
+				match('?');
+				break;
+			}
+			case '$':
+			{
+				match('$');
+				break;
+			}
+			case '^':
+			{
+				match('^');
+				break;
+			}
+			case '[':
+			{
+				match('[');
+				break;
+			}
+			case ']':
+			{
+				match(']');
+				break;
+			}
+			case '{':
+			{
+				match('{');
+				break;
+			}
+			case '}':
+			{
+				match('}');
+				break;
+			}
 			case 'a':
 			{
 				match('a');
@@ -2233,8 +2307,10 @@ _loop94_breakloop:			;
 			}
 			case 'c':
 			{
-				match('c');
-				matchRange('A','Z');
+				{
+					match('c');
+					matchRange('A','Z');
+				}
 				break;
 			}
 			case 't':
@@ -2272,7 +2348,7 @@ _loop94_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt117=0;
+					int _cnt106=0;
 					for (;;)
 					{
 						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_2_.member(cached_LA2)) && (true))
@@ -2281,29 +2357,33 @@ _loop94_breakloop:			;
 						}
 						else
 						{
-							if (_cnt117 >= 1) { goto _loop117_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt106 >= 1) { goto _loop106_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt117++;
+						_cnt106++;
 					}
-_loop117_breakloop:					;
+_loop106_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
 			case 'x':
 			{
-				match('x');
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
+				{
+					match('x');
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+				}
 				break;
 			}
 			case 'u':
 			{
-				match('u');
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
+				{
+					match('u');
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+				}
 				break;
 			}
 			case '\\':
@@ -2381,71 +2461,6 @@ _loop117_breakloop:					;
 				match('k');
 				break;
 			}
-			case '/':
-			{
-				match('/');
-				break;
-			}
-			case '(':
-			{
-				match('(');
-				break;
-			}
-			case ')':
-			{
-				match(')');
-				break;
-			}
-			case '|':
-			{
-				match('|');
-				break;
-			}
-			case '.':
-			{
-				match('.');
-				break;
-			}
-			case '*':
-			{
-				match('*');
-				break;
-			}
-			case '?':
-			{
-				match('?');
-				break;
-			}
-			case '$':
-			{
-				match('$');
-				break;
-			}
-			case '^':
-			{
-				match('^');
-				break;
-			}
-			case '[':
-			{
-				match('[');
-				break;
-			}
-			case ']':
-			{
-				match(']');
-				break;
-			}
-			case '{':
-			{
-				match('{');
-				break;
-			}
-			case '}':
-			{
-				match('}');
-				break;
-			}
 			default:
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
