@@ -107,92 +107,96 @@ using Boo.Lang.Parser.Util;
 		public const int IN = 43;
 		public const int NOT = 44;
 		public const int NULL = 45;
-		public const int OR = 46;
-		public const int OTHERWISE = 47;
-		public const int OVERRIDE = 48;
-		public const int PASS = 49;
-		public const int NAMESPACE = 50;
-		public const int PUBLIC = 51;
-		public const int PROTECTED = 52;
-		public const int PRIVATE = 53;
-		public const int RAISE = 54;
-		public const int REF = 55;
-		public const int RETURN = 56;
-		public const int RETRY = 57;
-		public const int SET = 58;
-		public const int SELF = 59;
-		public const int SUPER = 60;
-		public const int STATIC = 61;
-		public const int SUCCESS = 62;
-		public const int STRUCT = 63;
-		public const int TRY = 64;
-		public const int TRANSIENT = 65;
-		public const int TRUE = 66;
-		public const int TYPEOF = 67;
-		public const int UNLESS = 68;
-		public const int VIRTUAL = 69;
-		public const int WHEN = 70;
-		public const int WHILE = 71;
-		public const int YIELD = 72;
-		public const int EOS = 73;
-		public const int TRIPLE_QUOTED_STRING = 74;
-		public const int DOUBLE_QUOTED_STRING = 75;
-		public const int SINGLE_QUOTED_STRING = 76;
-		public const int ID = 77;
-		public const int LPAREN = 78;
-		public const int RPAREN = 79;
-		public const int ASSIGN = 80;
-		public const int SUBTRACT = 81;
-		public const int LBRACK = 82;
-		public const int COMMA = 83;
-		public const int RBRACK = 84;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 85;
-		public const int DOT = 86;
-		public const int COLON = 87;
-		public const int MULTIPLY = 88;
-		public const int BITWISE_OR = 89;
-		public const int LBRACE = 90;
-		public const int RBRACE = 91;
-		public const int INPLACE_BITWISE_OR = 92;
-		public const int INPLACE_BITWISE_AND = 93;
-		public const int INPLACE_SHIFT_LEFT = 94;
-		public const int INPLACE_SHIFT_RIGHT = 95;
-		public const int CMP_OPERATOR = 96;
-		public const int GREATER_THAN = 97;
-		public const int LESS_THAN = 98;
-		public const int ADD = 99;
-		public const int EXCLUSIVE_OR = 100;
-		public const int DIVISION = 101;
-		public const int MODULUS = 102;
-		public const int BITWISE_AND = 103;
-		public const int SHIFT_LEFT = 104;
-		public const int SHIFT_RIGHT = 105;
-		public const int EXPONENTIATION = 106;
-		public const int INCREMENT = 107;
-		public const int DECREMENT = 108;
-		public const int ONES_COMPLEMENT = 109;
-		public const int INT = 110;
-		public const int LONG = 111;
-		public const int RE_LITERAL = 112;
-		public const int DOUBLE = 113;
-		public const int FLOAT = 114;
-		public const int TIMESPAN = 115;
-		public const int LINE_CONTINUATION = 116;
-		public const int SL_COMMENT = 117;
-		public const int ML_COMMENT = 118;
-		public const int WS = 119;
-		public const int X_RE_LITERAL = 120;
-		public const int NEWLINE = 121;
-		public const int ESCAPED_EXPRESSION = 122;
-		public const int DQS_ESC = 123;
-		public const int SQS_ESC = 124;
-		public const int SESC = 125;
-		public const int RE_CHAR = 126;
-		public const int X_RE_CHAR = 127;
-		public const int RE_ESC = 128;
-		public const int ID_LETTER = 129;
-		public const int DIGIT = 130;
-		public const int HEXDIGIT = 131;
+		public const int OF = 46;
+		public const int OR = 47;
+		public const int OTHERWISE = 48;
+		public const int OVERRIDE = 49;
+		public const int PASS = 50;
+		public const int NAMESPACE = 51;
+		public const int PARTIAL = 52;
+		public const int PUBLIC = 53;
+		public const int PROTECTED = 54;
+		public const int PRIVATE = 55;
+		public const int RAISE = 56;
+		public const int REF = 57;
+		public const int RETURN = 58;
+		public const int RETRY = 59;
+		public const int SET = 60;
+		public const int SELF = 61;
+		public const int SUPER = 62;
+		public const int STATIC = 63;
+		public const int SUCCESS = 64;
+		public const int STRUCT = 65;
+		public const int TRY = 66;
+		public const int TRANSIENT = 67;
+		public const int TRUE = 68;
+		public const int TYPEOF = 69;
+		public const int UNLESS = 70;
+		public const int VIRTUAL = 71;
+		public const int WHEN = 72;
+		public const int WHILE = 73;
+		public const int YIELD = 74;
+		public const int EOS = 75;
+		public const int TRIPLE_QUOTED_STRING = 76;
+		public const int DOUBLE_QUOTED_STRING = 77;
+		public const int SINGLE_QUOTED_STRING = 78;
+		public const int ID = 79;
+		public const int LPAREN = 80;
+		public const int RPAREN = 81;
+		public const int ASSIGN = 82;
+		public const int SUBTRACT = 83;
+		public const int LBRACK = 84;
+		public const int COMMA = 85;
+		public const int RBRACK = 86;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 87;
+		public const int DOT = 88;
+		public const int COLON = 89;
+		public const int MULTIPLY = 90;
+		public const int BITWISE_OR = 91;
+		public const int LBRACE = 92;
+		public const int RBRACE = 93;
+		public const int INPLACE_BITWISE_OR = 94;
+		public const int INPLACE_BITWISE_AND = 95;
+		public const int INPLACE_SHIFT_LEFT = 96;
+		public const int INPLACE_SHIFT_RIGHT = 97;
+		public const int CMP_OPERATOR = 98;
+		public const int GREATER_THAN = 99;
+		public const int LESS_THAN = 100;
+		public const int ADD = 101;
+		public const int EXCLUSIVE_OR = 102;
+		public const int DIVISION = 103;
+		public const int MODULUS = 104;
+		public const int BITWISE_AND = 105;
+		public const int SHIFT_LEFT = 106;
+		public const int SHIFT_RIGHT = 107;
+		public const int EXPONENTIATION = 108;
+		public const int INCREMENT = 109;
+		public const int DECREMENT = 110;
+		public const int ONES_COMPLEMENT = 111;
+		public const int INT = 112;
+		public const int LONG = 113;
+		public const int RE_LITERAL = 114;
+		public const int DOUBLE = 115;
+		public const int FLOAT = 116;
+		public const int TIMESPAN = 117;
+		public const int LINE_CONTINUATION = 118;
+		public const int SL_COMMENT = 119;
+		public const int ML_COMMENT = 120;
+		public const int WS = 121;
+		public const int X_RE_LITERAL = 122;
+		public const int NEWLINE = 123;
+		public const int ESCAPED_EXPRESSION = 124;
+		public const int DQS_ESC = 125;
+		public const int SQS_ESC = 126;
+		public const int SESC = 127;
+		public const int RE_CHAR = 128;
+		public const int X_RE_CHAR = 129;
+		public const int RE_ESC = 130;
+		public const int DIGIT_GROUP = 131;
+		public const int REVERSE_DIGIT_GROUP = 132;
+		public const int ID_LETTER = 133;
+		public const int DIGIT = 134;
+		public const int HEXDIGIT = 135;
 		
 		
 	protected int _skipWhitespaceRegion = 0;
@@ -274,70 +278,72 @@ using Boo.Lang.Parser.Util;
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 51);
-			literals.Add("namespace", 50);
+			literals.Add("public", 53);
+			literals.Add("namespace", 51);
 			literals.Add("break", 13);
-			literals.Add("while", 71);
-			literals.Add("otherwise", 47);
-			literals.Add("raise", 54);
-			literals.Add("typeof", 67);
+			literals.Add("while", 73);
+			literals.Add("otherwise", 48);
+			literals.Add("raise", 56);
+			literals.Add("typeof", 69);
 			literals.Add("and", 10);
 			literals.Add("failure", 29);
 			literals.Add("not", 44);
-			literals.Add("return", 56);
-			literals.Add("pass", 49);
+			literals.Add("return", 58);
+			literals.Add("pass", 50);
 			literals.Add("from", 31);
 			literals.Add("null", 45);
 			literals.Add("def", 20);
 			literals.Add("given", 35);
-			literals.Add("protected", 52);
-			literals.Add("ref", 55);
-			literals.Add("retry", 57);
-			literals.Add("when", 70);
+			literals.Add("protected", 54);
+			literals.Add("ref", 57);
+			literals.Add("retry", 59);
+			literals.Add("when", 72);
 			literals.Add("class", 18);
 			literals.Add("do", 22);
 			literals.Add("except", 28);
 			literals.Add("event", 27);
 			literals.Add("ast", 12);
-			literals.Add("unless", 68);
-			literals.Add("super", 60);
-			literals.Add("set", 58);
-			literals.Add("transient", 65);
+			literals.Add("unless", 70);
+			literals.Add("super", 62);
+			literals.Add("set", 60);
+			literals.Add("transient", 67);
 			literals.Add("constructor", 19);
 			literals.Add("interface", 38);
+			literals.Add("of", 46);
 			literals.Add("is", 40);
 			literals.Add("internal", 39);
 			literals.Add("final", 30);
-			literals.Add("yield", 72);
-			literals.Add("or", 46);
+			literals.Add("yield", 74);
+			literals.Add("or", 47);
 			literals.Add("destructor", 21);
 			literals.Add("if", 42);
-			literals.Add("success", 62);
-			literals.Add("override", 48);
+			literals.Add("success", 64);
+			literals.Add("override", 49);
 			literals.Add("as", 11);
-			literals.Add("try", 64);
+			literals.Add("try", 66);
 			literals.Add("goto", 36);
 			literals.Add("enum", 26);
 			literals.Add("isa", 41);
 			literals.Add("for", 32);
 			literals.Add("char", 17);
-			literals.Add("private", 53);
+			literals.Add("private", 55);
 			literals.Add("false", 33);
-			literals.Add("static", 61);
+			literals.Add("static", 63);
 			literals.Add("abstract", 9);
+			literals.Add("partial", 52);
 			literals.Add("callable", 15);
 			literals.Add("get", 34);
 			literals.Add("continue", 14);
 			literals.Add("cast", 16);
-			literals.Add("struct", 63);
+			literals.Add("struct", 65);
 			literals.Add("else", 24);
 			literals.Add("import", 37);
 			literals.Add("elif", 23);
 			literals.Add("in", 43);
-			literals.Add("self", 59);
+			literals.Add("self", 61);
 			literals.Add("ensure", 25);
-			literals.Add("true", 66);
-			literals.Add("virtual", 69);
+			literals.Add("true", 68);
+			literals.Add("virtual", 71);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -639,11 +645,11 @@ tryAgain:
 				}
 				default:
 				{
-					goto _loop503_breakloop;
+					goto _loop529_breakloop;
 				}
 				 }
 			}
-_loop503_breakloop:			;
+_loop529_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -796,7 +802,7 @@ _loop503_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt508=0;
+					int _cnt534=0;
 					for (;;)
 					{
 						if ((tokenSet_0_.member(cached_LA1)))
@@ -805,12 +811,12 @@ _loop503_breakloop:			;
 						}
 						else
 						{
-							if (_cnt508 >= 1) { goto _loop508_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt534 >= 1) { goto _loop534_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt508++;
+						_cnt534++;
 					}
-_loop508_breakloop:					;
+_loop534_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -846,23 +852,7 @@ _loop508_breakloop:					;
 			}
 		}
 		else if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (true)) {
-			{ // ( ... )+
-				int _cnt512=0;
-				for (;;)
-				{
-					if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-					{
-						mDIGIT(false);
-					}
-					else
-					{
-						if (_cnt512 >= 1) { goto _loop512_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-					}
-					
-					_cnt512++;
-				}
-_loop512_breakloop:				;
-			}    // ( ... )+
+			mDIGIT_GROUP(false);
 			{
 				if ((cached_LA1=='E'||cached_LA1=='e'))
 				{
@@ -910,23 +900,7 @@ _loop512_breakloop:				;
 						}
 						 }
 					}
-					{ // ( ... )+
-						int _cnt517=0;
-						for (;;)
-						{
-							if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-							{
-								mDIGIT(false);
-							}
-							else
-							{
-								if (_cnt517 >= 1) { goto _loop517_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-							}
-							
-							_cnt517++;
-						}
-_loop517_breakloop:						;
-					}    // ( ... )+
+					mDIGIT_GROUP(false);
 				}
 				else {
 				}
@@ -999,23 +973,7 @@ _loop517_breakloop:						;
 								{
 									{
 										match('.');
-										{ // ( ... )+
-											int _cnt526=0;
-											for (;;)
-											{
-												if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-												{
-													mDIGIT(false);
-												}
-												else
-												{
-													if (_cnt526 >= 1) { goto _loop526_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-												}
-												
-												_cnt526++;
-											}
-_loop526_breakloop:											;
-										}    // ( ... )+
+										mREVERSE_DIGIT_GROUP(false);
 										{
 											if ((cached_LA1=='E'||cached_LA1=='e'))
 											{
@@ -1063,23 +1021,7 @@ _loop526_breakloop:											;
 													}
 													 }
 												}
-												{ // ( ... )+
-													int _cnt531=0;
-													for (;;)
-													{
-														if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-														{
-															mDIGIT(false);
-														}
-														else
-														{
-															if (_cnt531 >= 1) { goto _loop531_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-														}
-														
-														_cnt531++;
-													}
-_loop531_breakloop:													;
-												}    // ( ... )+
+												mDIGIT_GROUP(false);
 											}
 											else {
 											}
@@ -1231,6 +1173,100 @@ _loop531_breakloop:													;
 		returnToken_ = _token;
 	}
 	
+	protected void mDIGIT_GROUP(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = DIGIT_GROUP;
+		
+		mDIGIT(false);
+		{    // ( ... )*
+			for (;;)
+			{
+				switch ( cached_LA1 )
+				{
+				case '_':
+				{
+					{
+						int _saveIndex = 0;
+						_saveIndex = text.Length;
+						match('_');
+						text.Length = _saveIndex;
+						mDIGIT(false);
+						mDIGIT(false);
+						mDIGIT(false);
+					}
+					break;
+				}
+				case '0':  case '1':  case '2':  case '3':
+				case '4':  case '5':  case '6':  case '7':
+				case '8':  case '9':
+				{
+					mDIGIT(false);
+					break;
+				}
+				default:
+				{
+					goto _loop689_breakloop;
+				}
+				 }
+			}
+_loop689_breakloop:			;
+		}    // ( ... )*
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
+	protected void mREVERSE_DIGIT_GROUP(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = REVERSE_DIGIT_GROUP;
+		
+		{ // ( ... )+
+			int _cnt693=0;
+			for (;;)
+			{
+				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
+				{
+					mDIGIT(false);
+					mDIGIT(false);
+					mDIGIT(false);
+					{
+						if (((cached_LA1=='_'))&&(BooLexer.IsDigit(LA(2))))
+						{
+							int _saveIndex = 0;
+							_saveIndex = text.Length;
+							match('_');
+							text.Length = _saveIndex;
+						}
+						else {
+						}
+						
+					}
+				}
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (true) && (true)) {
+					mDIGIT(false);
+				}
+				else
+				{
+					if (_cnt693 >= 1) { goto _loop693_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+				}
+				
+				_cnt693++;
+			}
+_loop693_breakloop:			;
+		}    // ( ... )+
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	public void mDOT(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -1240,23 +1276,7 @@ _loop531_breakloop:													;
 		{
 			if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
 			{
-				{ // ( ... )+
-					int _cnt540=0;
-					for (;;)
-					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-						{
-							mDIGIT(false);
-						}
-						else
-						{
-							if (_cnt540 >= 1) { goto _loop540_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-						}
-						
-						_cnt540++;
-					}
-_loop540_breakloop:					;
-				}    // ( ... )+
+				mREVERSE_DIGIT_GROUP(false);
 				{
 					if ((cached_LA1=='E'||cached_LA1=='e'))
 					{
@@ -1304,23 +1324,7 @@ _loop540_breakloop:					;
 							}
 							 }
 						}
-						{ // ( ... )+
-							int _cnt545=0;
-							for (;;)
-							{
-								if (((cached_LA1 >= '0' && cached_LA1 <= '9')))
-								{
-									mDIGIT(false);
-								}
-								else
-								{
-									if (_cnt545 >= 1) { goto _loop545_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
-								}
-								
-								_cnt545++;
-							}
-_loop545_breakloop:							;
-						}    // ( ... )+
+						mDIGIT_GROUP(false);
 					}
 					else {
 					}
@@ -1578,11 +1582,11 @@ _loop545_breakloop:							;
 			EnterSkipWhitespaceRegion();
 		}
 		{
-			bool synPredMatched564 = false;
+			bool synPredMatched578 = false;
 			if (((cached_LA1=='a')))
 			{
-				int _m564 = mark();
-				synPredMatched564 = true;
+				int _m578 = mark();
+				synPredMatched578 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1591,12 +1595,12 @@ _loop545_breakloop:							;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched564 = false;
+					synPredMatched578 = false;
 				}
-				rewind(_m564);
+				rewind(_m578);
 				inputState.guessing--;
 			}
-			if ( synPredMatched564 )
+			if ( synPredMatched578 )
 			{
 				match("assembly:");
 				if (0==inputState.guessing)
@@ -1816,11 +1820,11 @@ _loop545_breakloop:							;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched582 = false;
+		bool synPredMatched596 = false;
 		if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 		{
-			int _m582 = mark();
-			synPredMatched582 = true;
+			int _m596 = mark();
+			synPredMatched596 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1829,12 +1833,12 @@ _loop545_breakloop:							;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched582 = false;
+				synPredMatched596 = false;
 			}
-			rewind(_m582);
+			rewind(_m596);
 			inputState.guessing--;
 		}
-		if ( synPredMatched582 )
+		if ( synPredMatched596 )
 		{
 			mML_COMMENT(false);
 			if (0==inputState.guessing)
@@ -1843,11 +1847,11 @@ _loop545_breakloop:							;
 			}
 		}
 		else {
-			bool synPredMatched584 = false;
+			bool synPredMatched598 = false;
 			if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
 			{
-				int _m584 = mark();
-				synPredMatched584 = true;
+				int _m598 = mark();
+				synPredMatched598 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1856,12 +1860,12 @@ _loop545_breakloop:							;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched584 = false;
+					synPredMatched598 = false;
 				}
-				rewind(_m584);
+				rewind(_m598);
 				inputState.guessing--;
 			}
-			if ( synPredMatched584 )
+			if ( synPredMatched598 )
 			{
 				mRE_LITERAL(false);
 				if (0==inputState.guessing)
@@ -1889,11 +1893,11 @@ _loop545_breakloop:							;
 									}
 									else
 									{
-										goto _loop589_breakloop;
+										goto _loop603_breakloop;
 									}
 									
 								}
-_loop589_breakloop:								;
+_loop603_breakloop:								;
 							}    // ( ... )*
 							if (0==inputState.guessing)
 							{
@@ -1946,11 +1950,11 @@ _loop589_breakloop:								;
 					match('*');
 				}
 				else {
-					bool synPredMatched630 = false;
+					bool synPredMatched644 = false;
 					if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m630 = mark();
-						synPredMatched630 = true;
+						int _m644 = mark();
+						synPredMatched644 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -1959,12 +1963,12 @@ _loop589_breakloop:								;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched630 = false;
+							synPredMatched644 = false;
 						}
-						rewind(_m630);
+						rewind(_m644);
 						inputState.guessing--;
 					}
-					if ( synPredMatched630 )
+					if ( synPredMatched644 )
 					{
 						mML_COMMENT(false);
 					}
@@ -1978,11 +1982,11 @@ _loop589_breakloop:								;
 					}
 					else
 					{
-						goto _loop632_breakloop;
+						goto _loop646_breakloop;
 					}
 					}
 				}
-_loop632_breakloop:				;
+_loop646_breakloop:				;
 			}    // ( ... )*
 			match("*/");
 			if (0==inputState.guessing)
@@ -2004,7 +2008,7 @@ _loop632_breakloop:				;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt661=0;
+			int _cnt675=0;
 			for (;;)
 			{
 				if ((tokenSet_1_.member(cached_LA1)))
@@ -2013,12 +2017,12 @@ _loop632_breakloop:				;
 				}
 				else
 				{
-					if (_cnt661 >= 1) { goto _loop661_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt675 >= 1) { goto _loop675_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt661++;
+				_cnt675++;
 			}
-_loop661_breakloop:			;
+_loop675_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -2237,12 +2241,12 @@ _loop661_breakloop:			;
 			for (;;)
 			{
 				// nongreedy exit test
-				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop610_breakloop;
-				bool synPredMatched606 = false;
+				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop624_breakloop;
+				bool synPredMatched620 = false;
 				if (((cached_LA1=='$') && (cached_LA2=='{') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 				{
-					int _m606 = mark();
-					synPredMatched606 = true;
+					int _m620 = mark();
+					synPredMatched620 = true;
 					inputState.guessing++;
 					try {
 						{
@@ -2251,12 +2255,12 @@ _loop661_breakloop:			;
 					}
 					catch (RecognitionException)
 					{
-						synPredMatched606 = false;
+						synPredMatched620 = false;
 					}
-					rewind(_m606);
+					rewind(_m620);
 					inputState.guessing--;
 				}
-				if ( synPredMatched606 )
+				if ( synPredMatched620 )
 				{
 					if (0==inputState.guessing)
 					{
@@ -2268,11 +2272,11 @@ _loop661_breakloop:			;
 					mESCAPED_EXPRESSION(false);
 				}
 				else {
-					bool synPredMatched608 = false;
+					bool synPredMatched622 = false;
 					if (((cached_LA1=='\\') && (cached_LA2=='$') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m608 = mark();
-						synPredMatched608 = true;
+						int _m622 = mark();
+						synPredMatched622 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2281,12 +2285,12 @@ _loop661_breakloop:			;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched608 = false;
+							synPredMatched622 = false;
 						}
-						rewind(_m608);
+						rewind(_m622);
 						inputState.guessing--;
 					}
-					if ( synPredMatched608 )
+					if ( synPredMatched622 )
 					{
 						_saveIndex = text.Length;
 						match('\\');
@@ -2303,11 +2307,11 @@ _loop661_breakloop:			;
 					}
 					else
 					{
-						goto _loop610_breakloop;
+						goto _loop624_breakloop;
 					}
 					}
 				}
-_loop610_breakloop:				;
+_loop624_breakloop:				;
 			}    // ( ... )*
 			_saveIndex = text.Length;
 			match("\"\"\"");
@@ -2375,11 +2379,11 @@ _loop610_breakloop:				;
 					{    // ( ... )*
 						for (;;)
 						{
-							bool synPredMatched616 = false;
+							bool synPredMatched630 = false;
 							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_3_.member(LA(3)))))
 							{
-								int _m616 = mark();
-								synPredMatched616 = true;
+								int _m630 = mark();
+								synPredMatched630 = true;
 								inputState.guessing++;
 								try {
 									{
@@ -2388,12 +2392,12 @@ _loop610_breakloop:				;
 								}
 								catch (RecognitionException)
 								{
-									synPredMatched616 = false;
+									synPredMatched630 = false;
 								}
-								rewind(_m616);
+								rewind(_m630);
 								inputState.guessing--;
 							}
-							if ( synPredMatched616 )
+							if ( synPredMatched630 )
 							{
 								if (0==inputState.guessing)
 								{
@@ -2414,11 +2418,11 @@ _loop610_breakloop:				;
 							}
 							else
 							{
-								goto _loop618_breakloop;
+								goto _loop632_breakloop;
 							}
 							
 						}
-_loop618_breakloop:						;
+_loop632_breakloop:						;
 					}    // ( ... )*
 					_saveIndex = text.Length;
 					match('"');
@@ -2517,11 +2521,11 @@ _loop618_breakloop:						;
 				}
 				else
 				{
-					goto _loop622_breakloop;
+					goto _loop636_breakloop;
 				}
 				
 			}
-_loop622_breakloop:			;
+_loop636_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2589,11 +2593,11 @@ _loop622_breakloop:			;
 				}
 				else
 				{
-					goto _loop626_breakloop;
+					goto _loop640_breakloop;
 				}
 				
 			}
-_loop626_breakloop:			;
+_loop640_breakloop:			;
 		}    // ( ... )*
 		if (0==inputState.guessing)
 		{
@@ -2613,7 +2617,7 @@ _loop626_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt635=0;
+			int _cnt649=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -2640,12 +2644,12 @@ _loop626_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt635 >= 1) { goto _loop635_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt649 >= 1) { goto _loop649_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt635++;
+				_cnt649++;
 			}
-_loop635_breakloop:			;
+_loop649_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -2689,7 +2693,7 @@ _loop635_breakloop:			;
 		text.Length = _saveIndex;
 		match('/');
 		{ // ( ... )+
-			int _cnt639=0;
+			int _cnt653=0;
 			for (;;)
 			{
 				if ((tokenSet_7_.member(cached_LA1)))
@@ -2698,12 +2702,12 @@ _loop635_breakloop:			;
 				}
 				else
 				{
-					if (_cnt639 >= 1) { goto _loop639_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt653 >= 1) { goto _loop653_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt639++;
+				_cnt653++;
 			}
-_loop639_breakloop:			;
+_loop653_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (0==inputState.guessing)
@@ -2943,6 +2947,76 @@ _loop639_breakloop:			;
 		{
 			switch ( cached_LA1 )
 			{
+			case '+':
+			{
+				match('+');
+				break;
+			}
+			case '/':
+			{
+				match('/');
+				break;
+			}
+			case '(':
+			{
+				match('(');
+				break;
+			}
+			case ')':
+			{
+				match(')');
+				break;
+			}
+			case '|':
+			{
+				match('|');
+				break;
+			}
+			case '.':
+			{
+				match('.');
+				break;
+			}
+			case '*':
+			{
+				match('*');
+				break;
+			}
+			case '?':
+			{
+				match('?');
+				break;
+			}
+			case '$':
+			{
+				match('$');
+				break;
+			}
+			case '^':
+			{
+				match('^');
+				break;
+			}
+			case '[':
+			{
+				match('[');
+				break;
+			}
+			case ']':
+			{
+				match(']');
+				break;
+			}
+			case '{':
+			{
+				match('{');
+				break;
+			}
+			case '}':
+			{
+				match('}');
+				break;
+			}
 			case 'a':
 			{
 				match('a');
@@ -2955,8 +3029,10 @@ _loop639_breakloop:			;
 			}
 			case 'c':
 			{
-				match('c');
-				matchRange('A','Z');
+				{
+					match('c');
+					matchRange('A','Z');
+				}
 				break;
 			}
 			case 't':
@@ -2994,7 +3070,7 @@ _loop639_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt668=0;
+					int _cnt683=0;
 					for (;;)
 					{
 						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_3_.member(cached_LA2)) && (true))
@@ -3003,29 +3079,33 @@ _loop639_breakloop:			;
 						}
 						else
 						{
-							if (_cnt668 >= 1) { goto _loop668_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt683 >= 1) { goto _loop683_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt668++;
+						_cnt683++;
 					}
-_loop668_breakloop:					;
+_loop683_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
 			case 'x':
 			{
-				match('x');
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
+				{
+					match('x');
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+				}
 				break;
 			}
 			case 'u':
 			{
-				match('u');
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
-				mHEXDIGIT(false);
+				{
+					match('u');
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+					mHEXDIGIT(false);
+				}
 				break;
 			}
 			case '\\':
@@ -3103,71 +3183,6 @@ _loop668_breakloop:					;
 				match('k');
 				break;
 			}
-			case '/':
-			{
-				match('/');
-				break;
-			}
-			case '(':
-			{
-				match('(');
-				break;
-			}
-			case ')':
-			{
-				match(')');
-				break;
-			}
-			case '|':
-			{
-				match('|');
-				break;
-			}
-			case '.':
-			{
-				match('.');
-				break;
-			}
-			case '*':
-			{
-				match('*');
-				break;
-			}
-			case '?':
-			{
-				match('?');
-				break;
-			}
-			case '$':
-			{
-				match('$');
-				break;
-			}
-			case '^':
-			{
-				match('^');
-				break;
-			}
-			case '[':
-			{
-				match('[');
-				break;
-			}
-			case ']':
-			{
-				match(']');
-				break;
-			}
-			case '{':
-			{
-				match('{');
-				break;
-			}
-			case '}':
-			{
-				match('}');
-				break;
-			}
 			default:
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
